@@ -1591,7 +1591,7 @@ def test_error_response():
         raise ErrorResponse("iips!", 499)
     client = app.test_client()
     res = check(499, client.get("/iips"))
-    assert res.headers["Content-Type"] == "text/json"
+    assert res.headers["Content-Type"] == "application/json"
     assert b'"iips!"' == res.data
     # again, with FSA_ERROR_RESPONSE "json:*"
     app = af.create_app(FSA_ERROR_RESPONSE="json:BLA")
@@ -1600,7 +1600,7 @@ def test_error_response():
         raise ErrorResponse("uups!", 499)
     client = app.test_client()
     res = check(499, client.get("/uups"))
-    assert res.headers["Content-Type"] == "text/json"
+    assert res.headers["Content-Type"] == "application/json"
     assert b'{"BLA": "uups!"}' == res.data
     # again, with FSA_ERROR_RESPONSE callable
     app = af.create_app(FSA_ERROR_RESPONSE=oops)
@@ -1639,6 +1639,21 @@ def test_error_response():
     app._fsa._error_response = erh
     app.config.update(FSA_ERROR_RESPONSE="json", FSA_SECURE=False)
     app._fsa.initialize()
+    # check that we take control of flask errors
+    app = fsa.Flask("not-implemented", FSA_ERROR_RESPONSE="json:bad")
+    @app.get("/implemented", authorize="ANY")
+    def get_implemented():
+        raise ErrorResponse("oops", 418)
+    with app.test_client() as client:
+        res = check(418, client.get("/implemented"))
+        assert res.content_type == "application/json"
+        assert b'"bad":' in res.data
+        res = check(405, client.post("/implemented"))
+        assert res.content_type == "application/json"
+        assert b'"bad":' in res.data
+        res = check(404, client.get("/not-implemented"))
+        assert res.content_type == "application/json"
+        assert b'"bad":' in res.data
 
 def test_add_headers():
     import AppFact as af
